@@ -1,5 +1,5 @@
 package ExtUtils::HasCompiler;
-$ExtUtils::HasCompiler::VERSION = '0.003';
+$ExtUtils::HasCompiler::VERSION = '0.004';
 use strict;
 use warnings;
 
@@ -38,7 +38,7 @@ sub can_compile_executable {
 	_write_file($source_handle, $executable_code);
 
 	my $config = $args{config} || 'ExtUtils::HasCompiler::Config';
-	my ($cc, $ccflags, $ldflags, $libs) = map { $args{$_} || $ENV{uc $_} || $config->get($_) } qw/cc ccflags ldflags libs/;
+	my ($cc, $ccflags, $ldflags, $libs) = map { $config->get($_) } qw/cc ccflags ldflags libs/;
 	my $executable = catfile($tempdir, basename($source_name, '.c') . $config->get('_exe'));
 
 	my $command;
@@ -116,7 +116,7 @@ sub can_compile_loadable_object {
 	_write_file($source_handle, $loadable_object_code);
 
 	my $config = $args{config} || 'ExtUtils::HasCompiler::Config';
-	my ($cc, $ccflags, $optimize, $cccdlflags, $lddlflags, $perllibs, $archlibexp) = map { $args{$_} || $ENV{uc $_} || $config->get($_) } qw/cc ccflags optimize cccdlflags lddlflags perllibs archlibexp/;
+	my ($cc, $ccflags, $optimize, $cccdlflags, $lddlflags, $perllibs, $archlibexp) = map { $config->get($_) } qw/cc ccflags optimize cccdlflags lddlflags perllibs archlibexp/;
 	my $incdir = catdir($archlibexp, 'CORE');
 
 	my $loadable_object = catfile($tempdir, $basename . '.' . $config->get('dlext'));
@@ -129,7 +129,7 @@ sub can_compile_loadable_object {
 		ExtUtils::Mksymlists::Mksymlists(NAME => $basename, FILE => $abs_basename);
 		$command = qq{$cc $ccflags $optimize /I "$incdir" $source_name $abs_basename.def /Fo$abs_basename.obj /Fd$abs_basename.pdb /link $lddlflags $perllibs /out:$loadable_object};
 	}
-	if ($^O eq 'VMS') {
+	elsif ($^O eq 'VMS') {
 		warn "VMS is currently unsupported";
 		return;
 	}
@@ -142,7 +142,7 @@ sub can_compile_loadable_object {
 	}
 
 	print "$command\n" if not $args{quiet};
-	system $command and die "Couldn't execute command: $!";
+	system $command and die "Couldn't execute $command: $!";
 
 	# Skip loading when cross-compiling
 	return 1 if exists $args{skip_load} ? $args{skip_load} : $config->get('usecrosscompile');
@@ -162,7 +162,7 @@ sub can_compile_loadable_object {
 
 sub ExtUtils::HasCompiler::Config::get {
 	my (undef, $key) = @_;
-	return $Config{$key};
+	return $ENV{uc $key} || $Config{$key};
 }
 
 1;
@@ -181,7 +181,7 @@ ExtUtils::HasCompiler - Check for the presence of a compiler
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 DESCRIPTION
 
